WWTJupyterWidget
================

.. currentmodule:: pywwt.jupyter

.. autoclass:: WWTJupyterWidget
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~WWTJupyterWidget.layer_controls

   .. rubric:: Attributes Documentation

   .. autoattribute:: layer_controls
